@@ -4,9 +4,10 @@ use warnings;
 use Games::Jumble;
 
 my $jumble = Games::Jumble->new;
-$jumble->num_words(6);
-$jumble->word_length_allow(5,6);
-$jumble->dict('/home/doug/crossword_dict/unixdict.txt');
+$jumble->set_num_words(6);
+$jumble->set_word_lengths_allowed(5,6);
+$jumble->set_word_lengths_not_allowed(3);
+$jumble->set_dict('/home/doug/crossword_dict/unixdict.txt');
 
 my @jumble = $jumble->create_jumble;
 
