@@ -4,7 +4,7 @@ use warnings;
 use Games::Jumble;
 
 my $jumble = Games::Jumble->new;
-$jumble->dict('/home/doug/crossword_dict/unixdict.txt');
+$jumble->set_dict('/home/doug/crossword_dict/unixdict.txt');
 my @good_words = $jumble->solve_word('rta');
 
 if (@good_words) {
