@@ -4,7 +4,7 @@ use warnings;
 use Games::Jumble;
 
 my $jumble = Games::Jumble->new;
-$jumble->dict('/home/doug/crossword_dict/unixdict.txt');
+$jumble->set_dict('/home/doug/crossword_dict/unixdict.txt');
 
 my $word = 'camel';
 my $jumbled_word = $jumble->jumble_word($word);
